#!/usr/bin/python

DOCUMENTATION = '''
---
module: dcos_group_member
short_description: Manage groups members on DCOS
options:
    gid:
        description:
            - The unique name for the group account.
        required: true
    uid:
        description:
            - The uid of a user
        required: true
    state:
        description:
            - If C(present), ensure the group exists. If C(absent),
            ensure the group does not exists. Defaults to C(present).
        required: false
        default: present
        choices: [ present, absent ]
'''

EXAMPLES = '''
- name: Add a DCOS group member
  dcos_group_member:
     gid: "mygroupname"
     uid: "myuid1"

- name: Remove a DCOS group member
  dcos_group_member:
     gid: "mygroupname"
     uid: "myuid1"
     state: absent
'''

from ansible.module_utils.basic import *
from ansible.module_utils import dcos


def dcos_group_member_absent(params):
    client = dcos.DcosClient()
    gid = params['gid']
    uid = params['uid']
    path = '/groups/{gid}/users/{uid}'.format(gid=gid, uid=uid)
    result = client.delete(path)
    module.exit_json(**result)


def dcos_group_member_present(params):
    client = dcos.DcosClient()
    gid = params['gid']
    uid = params['uid']
    path = '/groups/{gid}/users/{uid}'.format(gid=gid, uid=uid)
    result = client.put(path, {})
    if result['changed']:
        module.exit_json(**result)
    elif result['status_code'] != 409:
        module.fail_json(**result)
    result['changed'] = False
    result['failed'] = False
    result['rc'] = 0
    module.exit_json(**result)


def main():
    global module
    module = AnsibleModule(argument_spec={
        'gid': { 'type': 'str', 'required': True },
        'uid': { 'type': 'str', 'required': True },
        'state': {
            'type': 'str',
            'required': False,
            'default': 'present',
            'choices': [ 'present', 'absent' ]
        },
    })
    if module.params['state'] == 'present':
        dcos_group_member_present(module.params)
    else:
        dcos_group_member_absent(module.params)


if __name__ == '__main__':
    main()



#!/usr/bin/python

DOCUMENTATION = '''
---
module: dcos_group
short_description: Manage groups on DCOS
options:
    gid:
        description:
            - The unique name for the group account.
        required: true
    description:
        description:
            - Optional group description during group creation.
        required: false
    state:
        description:
            - If C(present), ensure the group exists. If C(absent),
            ensure the group does not exists. Defaults to C(present).
        required: false
        default: present
        choices: [ present, absent ]
'''

EXAMPLES = '''
- name: Create a DCOS group
  dcos_group:
     gid: "mygroupname"
     description: "My first group"

- name: Remove a DCOS group
  dcos_group:
     uid: "mygroupname"
     state: absent
'''

from ansible.module_utils.basic import *
from ansible.module_utils import dcos


def dcos_group_absent(params):
    client = dcos.DcosClient()
    result = client.delete('/groups/{}'.format(params['gid']))
    module.exit_json(**result)


def dcos_group_present(params):
    client = dcos.DcosClient()
    body = {
        'description': params['description']
    }
    path = '/groups/{}'.format(params['gid'])
    result = client.put(path, body)
    if result['changed']:
        module.exit_json(**result)
    elif result['status_code'] != 409:
        module.fail_json(**result)
    result = client.patch(path, body)
    module.exit_json(**result)


def main():
    global module
    module = AnsibleModule(argument_spec={
        'gid': { 'type': 'str', 'required': True },
        'description': { 'type': 'str', 'required': False },
        'state': {
            'type': 'str',
            'required': False,
            'default': 'present',
            'choices': [ 'present', 'absent' ]
        },
    })
    if module.params['state'] == 'present':
        if module.params['description']:
            dcos_group_present(module.params)
        module.fail_json(msg="User list and description required for state=present", rc=1)
    dcos_group_absent(module.params)


if __name__ == '__main__':
    main()



#!/usr/bin/python

DOCUMENTATION = '''
---
module: dcos_acl_group
short_description: Manage acl groups
options:
    rid:
        description:
            - Identifier of the resource being controlled.
        required: true
    gid:
        description:
            - Group id to modify.
        required: false
    permission:
        description:
            - Permission on the resource e.g. read, full, ...
        required: false
    state:
        description:
            - If C(present), add the permission to the resource.
            If C(absent), remove the permission from the resource.
            Defaults to C(present).
        required: false
        default: present
        choices: [ present, absent ]
'''

EXAMPLES = '''
- name: Create the ACL for resource
  dcos_acl_group:
     rid: "dcos:adminrouter:ops:metadata"
     gid: "bobs"
     permission: "read"

- name: Remove the ACL for resource
  dcos_acl_group:
     rid: "dcos:adminrouter:ops:metadata"
     gid: "bobs"
     state: absent
'''

from ansible.module_utils.basic import *
from ansible.module_utils import dcos


def dcos_acl_group_absent(params):
    client = dcos.DcosClient()
    path = '/acls/{rid}/groups/{gid}/{permission}'.format(**params)
    result = client.delete(path)
    module.exit_json(**result)


def dcos_acl_group_present(params):
    client = dcos.DcosClient()
    body = {
        'description': params['rid']
    }
    path = '/acls/{rid}/groups/{gid}/{permission}'.format(**params)
    result = client.put(path)
    module.exit_json(**result)


def main():
    global module
    module = AnsibleModule(argument_spec={
        'rid': { 'type': 'str', 'required': True },
        'gid': { 'type': 'str', 'required': True },
        'permission': { 'type': 'str', 'required': True },
        'state': {
            'type': 'str',
            'required': False,
            'default': 'present',
            'choices': [ 'present', 'absent' ]
        },
    })
    if module.params['state'] == 'present':
        dcos_acl_group_present(module.params)
        module.fail_json(msg="Description required for state=present", rc=1)
    dcos_acl_group_absent(module.params)


if __name__ == '__main__':
    main()



#!/usr/bin/python

DOCUMENTATION = '''
---
module: dcos_user
short_description: Manage users on DCOS
options:
    uid:
        description:
            - The unique name for the user account.
        required: true
    password:
        description:
            - Password for the user account. Required for C(state=present).
        required: false
    description:
        description:
            - Optional account description during account creation.
        required: false
    reset_password:
        description:
            - Set the password if the user account exists regardless of
            whether the password has been changed by the user. This will
            always result in C(changed=true).
        required: false
        default: false
    state:
        description:
            - If C(present), ensure the user account exists. If C(absent),
            ensure the user account does not exists. Will not change the
            password for accounts that already exists, unless C(reset_password)
            is true. Defaults to C(present).
        required: false
        default: present
        choices: [ present, absent ]
'''

EXAMPLES = '''
- name: Create a DCOS user
  dcos_user:
     uid: "myusername"
     password: "s3cr3t"
     description: "My first user account"

- name: Remove a DCOS user
  dcos_user:
     uid: "myusername"
     state: absent
'''

from ansible.module_utils.basic import *
from ansible.module_utils import dcos


def dcos_user_absent(params):
    client = dcos.DcosClient()
    result = client.delete('/users/{}'.format(params['uid']))
    module.exit_json(**result)


def dcos_user_present(params):
    body = {
        'description': params['description'],
        'password': params['password'],
    }
    client = dcos.DcosClient()
    result = client.put('/users/{}'.format(params['uid']), body=body)
    if result['changed']:
        module.exit_json(**result)
    elif result['status_code'] != 409:
        module.fail_json(**result)

    changed = False
    body = {}
    result = client.get('/users/{}'.format(params['uid']))
    description = result['json'].get('description')
    if description != params['description']:
        changed = True
        body['description'] = params['description']
    if params['reset_password']:
        changed = True
        body['password'] = params['password']

    if not changed:
        module.exit_json(**result)

    result = client.patch('/users/{}'.format(params['uid']), body=body)
    if result['status_code'] == 204:
        module.exit_json(**result)

    module.fail_json(**result)


def main():
    global module
    module = AnsibleModule(argument_spec={
        'uid': { 'type': 'str', 'required': True },
        'password': { 'type': 'str', 'required': False },
        'description': { 'type': 'str', 'required': False },
        'reset_password': { 'type': 'bool', 'required': False, 'default': False },
        'state': {
            'type': 'str',
            'required': False,
            'default': 'present',
            'choices': [ 'present', 'absent' ]
        },
    })
    if module.params['state'] == 'present':
        if module.params['password'] and module.params['description']:
            dcos_user_present(module.params)
        else:
            module.fail_json(msg="Password and description required for state=present", rc=1)
    else:
        dcos_user_absent(module.params)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
from distutils.core import setup

files = [
    "ansible/module_utils",
    "ansible/modules/dcos",
]

long_description = """

Ansible modules for Mesospher DC/OS.  Modules exist to create users, groups and acls.

Usage
-----

The following example creates user bob::

    ---
    - hosts: localhost
      tasks:
        - dcos_user: 
            uid: "bobslydell"
            description: 'Bob Slydell'
            password: 'fooBar123ASDF'
            state: present

"""

setup(name='ansible-modules-dcos',
      version='1.0.2',
      description='DCOS Ansible Modules',
      long_description=long_description,
      url='https://github.com/TerryHowe/ansible-modules-dcos',
      author='Kevin Wood',
      author_email='kevin.wood@example.com',
      license='MIT',
      packages=files,
      requires = [
        'ansible (>2.0.0)',
        'dcoscli (>0.4.5)',
        'toml',
      ],
)



#!/usr/bin/python

DOCUMENTATION = '''
---
module: dcos_acl
short_description: Manage ACLs on DCOS
options:
    rid:
        description:
            - Identifier of the resource being controlled.
        required: true
    description:
        description:
            - Optional ACL description used during ACL creation.
        required: false
    state:
        description:
            - If C(present), ensure the ACL exists with all the listed
            group and user permissions set. If C(absent), ensure the ACL
            does not exists. Defaults to C(present).
        required: false
        default: present
        choices: [ present, absent ]
'''

EXAMPLES = '''
- name: Create the ACL for package management
  dcos_acl:
     rid: "dcos:adminrouter:package"
     description: "Package management ACL"

- name: Remove the ACL for package management
  dcos_acl:
     uid: "dcos:adminrouter:package"
     state: absent
'''

from ansible.module_utils.basic import *
from ansible.module_utils import dcos


def dcos_acl_absent(params):
    client = dcos.DcosClient()
    result = client.delete('/acls/{}'.format(params['rid']))
    module.exit_json(**result)


def dcos_acl_present(params):
    client = dcos.DcosClient()
    body = {
        'description': params['description']
    }
    path = '/acls/{}'.format(params['rid'])
    result = client.put(path, body)
    if result['changed']:
        module.exit_json(**result)
    elif result['status_code'] != 409:
        module.fail_json(**result)
    result = client.patch(path, body)
    module.exit_json(**result)


def main():
    global module
    module = AnsibleModule(argument_spec={
        'rid': { 'type': 'str', 'required': True },
        'description': { 'type': 'str', 'required': False },
        'state': {
            'type': 'str',
            'required': False,
            'default': 'present',
            'choices': [ 'present', 'absent' ]
        },
    })
    if module.params['state'] == 'present':
        if (module.params['description']):
            dcos_acl_present(module.params)
        module.fail_json(msg="Description required for state=present", rc=1)
    dcos_acl_absent(module.params)


if __name__ == '__main__':
    main()
